function imageRotator() {
    var imageRotator = this;
	this.isPaused = false;
    this.initialFadeIn = 500;
    this.itemInterval = 1000;
    this.readingInterval = 2000;
    this.currentItem = null;
    this.latestFrameHold = 4;
    this.latestFrameHoldCounter = 0;
    this.infiniteLoop = null;
    
    this.enable = function() {
		if(imageRotator.isPaused === true) {
			return;
		}
		
        if(radarData.transparent === null) {
            return;
        }
        if(imageRotator.currentItem === null) {
            imageRotator.currentItem = radarData.transparent.length - 1;
        }
		
		$("#slide").attr("max", radarData.transparent.length - 1);
		$("#slide").val(imageRotator.currentItem);

        $('#radar-transparent').attr("src", radarData.transparent[imageRotator.currentItem]);
        $('#radar-transparent').css("display", "block");
        
        imageRotator.infiniteLoop = setInterval(function(){
            if(imageRotator.currentItem >= radarData.transparent.length - 1){
                imageRotator.currentItem = radarData.transparent.length - 1;
                if(imageRotator.latestFrameHoldCounter <= imageRotator.latestFrameHold) {
                    imageRotator.latestFrameHoldCounter++;
                }
                else {
                    imageRotator.latestFrameHoldCounter = 0;
                    imageRotator.currentItem = 0;
                }
            }else{
                imageRotator.currentItem++;
            }
            $('#radar-transparent').attr("src", radarData.transparent[imageRotator.currentItem]);
			$("#slide").val(imageRotator.currentItem);
            var date = imageRotator.getCurrentItemTime(radarData.transparent[imageRotator.currentItem]);
			if(date.indexOf("date") == -1) {
 				$(".radar-label .image-time").text(date);
 			}
        }, imageRotator.getIntervalTime());
    };

    this.disable = function() {
        clearInterval(imageRotator.infiniteLoop);
    };
	
	this.showSelectedImage = function(selectedImageIndex) {
		$(".radar-loader").show();
		imageRotator.currentItem = selectedImageIndex;
		
		var date = imageRotator.getCurrentItemTime(radarData.transparent[imageRotator.currentItem]);
		if(date.indexOf("date") == -1) {
			$(".radar-label .image-time").text(date);
		}

		$('#radar-transparent').attr("src", radarData.transparent[imageRotator.currentItem]);
		$(".radar-loader").hide();
	};
    
    this.getCurrentItemTime = function(imageUrl) {
		var timestamp;
		var multiplier;
		var diff;

		switch(radarType) {
            case "rain_amount":
			case "temp":
			case "wind":
			case "snow_depth":
				timestamp = imageUrl.substring(45, 57);
				multiplier = 0;
				break;
			case "sun":
				timestamp = imageUrl.substring(44, 56);
				multiplier = 0;
				break;
			case "rain_region_nowcast":
			case "rain_national_nowcast":
				timestamp = imageUrl.substring(47, 59);
				multiplier = 0;
				if(imageUrl.indexOf("nowcast") != -1) {
					timestamp = imageUrl.substring(49, 61);
					multiplier = parseInt(imageUrl.substring(62, 64)) * 5;
				}
				else {
					timestamp = imageUrl.substring(47, 59);
					multiplier = 0;
				}
				break;
			case "infrared":
				timestamp = imageUrl.substring(48, 60);
				multiplier = 0;
				break;
			case "weather_chart":
				var substr = (imageUrl.length == 55) ? imageUrl.substring(43, 51) : imageUrl.substring(39, 47);
				timestamp = "20" + substr + "0000";
				multiplier = 0;
				break;
			case "rain_region_forecast":
			case "rain_national_forecast":
				timestamp = imageUrl.substring(45, 57);
				multiplier = 0;

				if(imageUrl.indexOf("-00") == -1) {
					multiplier = parseInt(imageUrl.substring(58, 60)) * 60;
				}
				break;
		}

		moment.locale('ja');
		var offset = moment().utcOffset();
		var imageDate = moment(timestamp, "YYYYMMDDHHmm").add(-9, 'hours');
		imageDate.add(offset, "minutes");
		imageDate.add(multiplier, "minutes");
		moment.locale('en');
		return imageDate.fromNow();
    };
    
    this.getIntervalTime = function() {
        switch(radarType) {
            case "rain_amount":
			case "temp":
			case "wind":
			case "snow_depth":
			case "sun":
				this.latestFrameHold = 2;
                return imageRotator.readingInterval;
            default:
				this.latestFrameHold = 2;
                return imageRotator.itemInterval;
        }
    };
}

$("#slide").on('touchstart', function(ev) {
	if(rainRadar.imageRotator !== null) {
		rainRadar.imageRotator.disable();
	}
});

$("#slide").on('touchend', function(ev) {
	if(rainRadar.imageRotator !== null) {
		if(rainRadar.imageRotator.isPaused === false) {
			rainRadar.imageRotator.enable();
		}
	}
});

$("#slide").on("input", function(ev){
	if(rainRadar.imageRotator !== null) {
		rainRadar.imageRotator.isPaused = true;
		$("#play-button").removeClass("fa-pause").addClass("fa-play");
		rainRadar.imageRotator.showSelectedImage(this.value);
	}
});

$("#play-button").on("touchstart", function(ev) {
	if(rainRadar.imageRotator !== null) {
		if(rainRadar.imageRotator.isPaused === false) {
			rainRadar.imageRotator.isPaused = true;
			rainRadar.imageRotator.disable();
			$("#play-button").removeClass("fa-pause").addClass("fa-play");
		}
		else {
			rainRadar.imageRotator.isPaused = false;
			rainRadar.imageRotator.enable();
			$("#play-button").removeClass("fa-play").addClass("fa-pause");
		}
	}
});
