var radarData = null;
var weatherData = null;

var userLat = null;
var userLong = null;
var userLocation = null;

var intervalRefreshData = null;
var timeoutUserLocationRetry = null;
var timeoutUserLocationPause = null;
var timeoutUserLocationOnResume = null;

var radarType = "rain_region_nowcast";
var appLoaded = false;

$(document).ready(function() {
   	document.addEventListener("deviceready", onDeviceReady, false);
    document.addEventListener("pause", onPause, false);
    document.addEventListener("resume", onResume, false);
   	setMapZoomEvents();
});

function onDeviceReady() {
	window.analytics.startTrackerWithId('UA-75972920-2');
	localforage.config(config.localforageConfig);
	onResume();
}

function onResume() {
	try {
		if(!window.isTablet) {
			window.screen.orientation.lock('portrait');
		}
	}
	catch(ev) {}

	try {
		if(window.MobileAccessibility){
        	window.MobileAccessibility.usePreferredTextZoom(false);
    	}
	}
	catch(ev) {}

    if(ads.isAdShowing() === false) {
		if(rainRadar.imageRotator !== null) {
			rainRadar.imageRotator.isPaused = false;
			$("#play-button").removeClass("fa-play").addClass("fa-pause");
		}

        if(appLoaded) {
			timeoutUserLocationOnResume = setTimeout(function() {
				rainRadar.getUserLocation();
			}, config.timer.userLocationPause);
		}
		else {
			rainRadar.getUserLocation();
			appLoaded = true;
		}

		ratings.showRateDialog().then(function(showRateDialog) {
			if(showRateDialog === false) {
				adsManager.runAds();
			}
		});

		menu.showLocationBookmarks();

		if($('.forecast').hasClass('show')) {
			forecast.showForecast();
		}

		radarCompass.startRadarCompass();
    }
    else {
		ads.setAdShowing(false);
		rainRadar.setIntervalRefreshData();
    }
}

function onPause() {
	rainRadar.resetZoom();
	clearTimers();

	if($('.forecast').hasClass('show')) {
		$('.forecast').hide();
		$('.forecast').removeClass('show');
	}
}

function clearTimers() {
	if(intervalRefreshData !== null) {
        clearInterval(intervalRefreshData);
        intervalRefreshData = null;
    }

    if(timeoutUserLocationRetry !== null) {
        clearTimeout(timeoutUserLocationRetry);
        timeoutUserLocationRetry = null;
    }

	if(timeoutUserLocationPause !== null) {
        clearTimeout(timeoutUserLocationPause);
        timeoutUserLocationPause = null;
    }

	if(timeoutUserLocationRetry !== null) {
        clearTimeout(timeoutUserLocationRetry);
        timeoutUserLocationRetry = null;
    }
}

var scrollValue = 0;
var scrollAdjusted = 0;

function setMapZoomEvents() {
	$(".radar-view").off("touchstart");
	$(".radar-view").off("touchend");
	if($(window).width() > 320 && $(window).width() <= 768) {
		$(".radar-view").on("touchstart", function(ev){		
			ev.preventDefault();
			var posX = $(this).offset().left;
			var posY = $(this).offset().top;
			var event = ev.originalEvent;
			rainRadar.setZoom(event.changedTouches[0].pageX - posX, event.changedTouches[0].pageY - posY);
		});
	}
	else {
		$(".radar-view").on("touchstart", function(ev){
			scrollValue = window.scrollY;
		});
		
		$(".radar-view").on("touchend", function(ev){
			scrollAdjusted = window.scrollY;
			if(scrollValue == scrollAdjusted) {
				ev.preventDefault();
				var posX = $(this).offset().left;
				var posY = $(this).offset().top;
				var event = ev.originalEvent;
				rainRadar.setZoom(event.changedTouches[0].pageX - posX, event.changedTouches[0].pageY - posY);
			}
		});
	}
}

$(window).resize(function() {
    if (ads.isAdShowing() === false) {
		setMapZoomEvents();
    	rainRadar.resize();
	}
});

$(".radar-select").on("touchend", function(ev){
	ev.preventDefault();
    if (!$(this).hasClass("selected")) {
        $(".selected").removeClass("selected");
        $("#radar-marker").removeClass("transition");

        $(this).addClass("selected");
        $(".radar-loader").show();
		radarType = $(this).data("type");
		
		if(rainRadar.imageRotator !== null) {
			rainRadar.imageRotator.isPaused = false;
			$("#play-button").removeClass("fa-play").addClass("fa-pause");
		}
		
		switch(radarType) {
			case "rain_region_nowcast":
			case "rain_national_nowcast":
			case "rain_region_forecast":
			case "rain_national_forecast":
				$(".image-time").css("width", "67px");
				break;
			default:
				$(".image-time").css("width", "74px");
		}

        if($("#radar-container").hasClass("zoom")) {
			$(".multiplier").hide();
			$("#radar-container").removeClass("zoom");
			$("#radar-container").on("transitionend webkitTransitionEnd", function(){
				$("#radar-container").off("transitionend webkitTransitionEnd");
				rainRadar.getRainRadar(false);
			});
		}
		else {
			rainRadar.getRainRadar(false);
		}
		window.analytics.trackEvent('main', 'main-select-' + radarType);
    }
});

$('.summary').on('touchstart', function(ev) {
	if($('.view-body').hasClass('open-menu') === false) {
		ev.stopPropagation();

		$('.forecast').show(0, function() {
			$('.forecast').on("transitionend webkitTransitionEnd", function(){
				$('.forecast').off("transitionend webkitTransitionEnd");
				forecast.scrollRefresh();
			});
			$('.forecast').addClass('show');
		});

		window.analytics.trackEvent('main', 'main-open-forecast');
	}
});

$(".bookmark").on("touchstart", function(ev) {
	ev.stopPropagation();
	if($("#bookmark-star").hasClass("fa-star-o")) {
		window.analytics.trackEvent('main', 'main-bookmark-location-add');
		locationManager.addCustomBookmark();
	}
	else {
		window.analytics.trackEvent('main', 'main-bookmark-location-delete');
		locationManager.deleteCustomBookmark();
	}
});

$(".popup").on("touchstart", function(ev) {
	ev.preventDefault();
	rainRadar.hidePopUp();
});

$('.popup-toggle').on('touchstart', function(ev) {
	ev.stopPropagation();
	menuEvents.openMenu();
});

